<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

// Project implemented by the "Recovery, Transformation and Resilience Plan.
// Funded by the European Union - Next GenerationEU".
//
// Produced by the UNIMOODLE University Group: Universities of
// Valladolid, Complutense de Madrid, UPV/EHU, León, Salamanca,
// Illes Balears, Valencia, Rey Juan Carlos, La Laguna, Zaragoza, Málaga,
// Córdoba, Extremadura, Vigo, Las Palmas de Gran Canaria y Burgos.

/**
 * Access.
 *
 * @package    local_coursetransfer
 * @copyright  2023 Proyecto UNIMOODLE
 * @author     UNIMOODLE Group (Coordinator) <direccion.area.estrategia.digital@uva.es>
 * @author     3IPUNT <contacte@tresipunt.com>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die;

$capabilities = [

    'local/coursetransfer:origin_view_courses' => [
        'captype' => 'read',
        'contextlevel' => CONTEXT_SYSTEM,
        'archetypes' => [
            'guest' => CAP_PROHIBIT,
            'manager' => CAP_ALLOW,
            'editingteacher' => CAP_ALLOW,
            'teacher' => CAP_PROHIBIT,
            'student' => CAP_PROHIBIT,
        ],
    ],

    'local/coursetransfer:origin_restore' => [
        'captype' => 'write',
        'contextlevel' => CONTEXT_SYSTEM,
        'archetypes' => [
            'guest' => CAP_PROHIBIT,
            'manager' => CAP_PROHIBIT,
            'editingteacher' => CAP_PROHIBIT,
            'teacher' => CAP_PROHIBIT,
            'student' => CAP_PROHIBIT,
        ],
    ],

    'local/coursetransfer:origin_restore_course' => [
        'captype' => 'write',
        'contextlevel' => CONTEXT_COURSE,
        'archetypes' => [
            'guest' => CAP_PROHIBIT,
            'manager' => CAP_ALLOW,
            'editingteacher' => CAP_ALLOW,
            'teacher' => CAP_PROHIBIT,
            'student' => CAP_PROHIBIT,
        ],
    ],

    'local/coursetransfer:origin_remove_course' => [
            'captype' => 'write',
            'contextlevel' => CONTEXT_COURSE,
            'archetypes' => [
                    'guest' => CAP_PROHIBIT,
                    'manager' => CAP_ALLOW,
                    'editingteacher' => CAP_PROHIBIT,
                    'teacher' => CAP_PROHIBIT,
                    'student' => CAP_PROHIBIT,
            ],
    ],

    'local/coursetransfer:origin_remove_category' => [
            'captype' => 'write',
            'contextlevel' => CONTEXT_SYSTEM,
            'archetypes' => [
                    'guest' => CAP_PROHIBIT,
                    'manager' => CAP_ALLOW,
                    'editingteacher' => CAP_PROHIBIT,
                    'teacher' => CAP_PROHIBIT,
                    'student' => CAP_PROHIBIT,
            ],
    ],

    'local/coursetransfer:origin_restore_course_users' => [
        'captype' => 'read',
        'contextlevel' => CONTEXT_COURSE,
        'archetypes' => [
            'guest' => CAP_PROHIBIT,
            'manager' => CAP_ALLOW,
            'editingteacher' => CAP_PROHIBIT,
            'teacher' => CAP_PROHIBIT,
            'student' => CAP_PROHIBIT,
        ],
    ],

    'local/coursetransfer:destiny_restore_enrol_remove' => [
            'captype' => 'write',
            'contextlevel' => CONTEXT_COURSE,
            'archetypes' => [
                    'guest' => CAP_PROHIBIT,
                    'manager' => CAP_ALLOW,
                    'editingteacher' => CAP_ALLOW,
                    'teacher' => CAP_PROHIBIT,
                    'student' => CAP_PROHIBIT,
            ],
    ],

    'local/coursetransfer:destiny_restore_groups_remove' => [
            'captype' => 'write',
            'contextlevel' => CONTEXT_COURSE,
            'archetypes' => [
                    'guest' => CAP_PROHIBIT,
                    'manager' => CAP_ALLOW,
                    'editingteacher' => CAP_ALLOW,
                    'teacher' => CAP_PROHIBIT,
                    'student' => CAP_PROHIBIT,
            ],
    ],

    'local/coursetransfer:destiny_restore_content_remove' => [
        'captype' => 'write',
        'contextlevel' => CONTEXT_COURSE,
        'archetypes' => [
            'guest' => CAP_PROHIBIT,
            'manager' => CAP_ALLOW,
            'editingteacher' => CAP_ALLOW,
            'teacher' => CAP_PROHIBIT,
            'student' => CAP_PROHIBIT,
        ],
    ],

    'local/coursetransfer:destiny_restore_merge' => [
        'captype' => 'write',
        'contextlevel' => CONTEXT_COURSE,
        'archetypes' => [
            'guest' => CAP_PROHIBIT,
            'manager' => CAP_ALLOW,
            'editingteacher' => CAP_ALLOW,
            'teacher' => CAP_PROHIBIT,
            'student' => CAP_PROHIBIT,
        ],
    ],

    'local/coursetransfer:view_logs' => [
        'captype' => 'read',
        'contextlevel' => CONTEXT_SYSTEM,
        'archetypes' => [
            'guest' => CAP_PROHIBIT,
            'manager' => CAP_ALLOW,
            'editingteacher' => CAP_PROHIBIT,
            'teacher' => CAP_PROHIBIT,
            'student' => CAP_PROHIBIT,
        ],
    ],

];
